#ifndef NT2_INCLUDE_CONSTANTS_SQRTEPS_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_SQRTEPS_HPP_INCLUDED

#include <nt2/constant/include/constants/sqrteps.hpp>

#endif
